@@ -18,7 +18,7 @@ import aiohttp
 _loggerName = 'beniutils'
 
 
-def bInitLogger(loggerName=None, loggerLevel=None, logFile=None):
+def initLogger(loggerName=None, loggerLevel=None, logFile=None):
     LOGGER_FORMAT = '%(asctime)s %(levelname)-1s %(message)s', '%Y-%m-%d %H:%M:%S'
     LOGGER_LEVEL = loggerLevel or logging.INFO
     LOGGER_LEVEL_NAME = {
@@ -46,39 +46,39 @@ def bInitLogger(loggerName=None, loggerLevel=None, logFile=None):
     logger.addHandler(loggerHandler)
 
     if logFile:
-        bMakeFolder(os.path.dirname(logFile))
+        makeFolder(os.path.dirname(logFile))
         fileLoggerHandler = logging.FileHandler(logFile)
         fileLoggerHandler.setFormatter(loggerFormatter)
         fileLoggerHandler.setLevel(LOGGER_LEVEL)
         logger.addHandler(fileLoggerHandler)
 
 
-def bDebug(msg, *args, **kwargs):
+def debug(msg, *args, **kwargs):
     logging.getLogger(_loggerName).debug(msg, *args, **kwargs)
 
 
-def bInfo(msg, *args, **kwargs):
+def info(msg, *args, **kwargs):
     logging.getLogger(_loggerName).info(msg, *args, **kwargs)
 
 
-def bWarning(msg, *args, **kwargs):
+def warning(msg, *args, **kwargs):
     logging.getLogger(_loggerName).warning(msg, *args, **kwargs)
 
 
-def bError(msg, *args, **kwargs):
+def error(msg, *args, **kwargs):
     logging.getLogger(_loggerName).error(msg, *args, **kwargs)
 
 
-def bCritical(msg, *args, **kwargs):
+def critical(msg, *args, **kwargs):
     logging.getLogger(_loggerName).critical(msg, *args, **kwargs)
 
 
-def bGetPath(basePath, *parList):
+def getPath(basePath, *parList):
     return os.path.abspath(os.path.join(basePath, *parList))
 
 
-def bWriteFile(file, data, encoding='utf8', newline='\n'):
-    bMakeFolder(os.path.dirname(file))
+def writeFile(file, data, encoding='utf8', newline='\n'):
+    makeFolder(os.path.dirname(file))
     with open(file, 'w', encoding=encoding, newline=newline) as f:
         f.write(data)
         f.flush()
@@ -86,8 +86,8 @@ def bWriteFile(file, data, encoding='utf8', newline='\n'):
     return file
 
 
-def bWriteBinFile(file, data):
-    bMakeFolder(os.path.dirname(file))
+def writeBinFile(file, data):
+    makeFolder(os.path.dirname(file))
     with open(file, 'wb') as f:
         f.write(data)
         f.flush()
@@ -95,68 +95,57 @@ def bWriteBinFile(file, data):
     return file
 
 
-def bReadFile(file, encoding='utf8', newline='\n'):
+def readFile(file, encoding='utf8', newline='\n'):
     with open(file, 'r', encoding=encoding, newline=newline) as f:
         data = f.read()
         f.close()
     return data
 
 
-def bReadBinFile(file):
+def readBinFile(file):
     with open(file, 'rb') as f:
         data = f.read()
         f.close()
     return data
 
 
-def bJsonDumps(value):
+def jsonDumps(value):
     return json.dumps(value, ensure_ascii=False, sort_keys=True, separators=(',', ':'))
 
 
-def bRemove(fileOrFolder):
-    if bIsFile(fileOrFolder):
+def remove(fileOrFolder):
+    if os.path.isfile(fileOrFolder):
         os.remove(fileOrFolder)
-    elif bIsFolder(fileOrFolder):
+    elif os.path.isdir(fileOrFolder):
         shutil.rmtree(fileOrFolder)
 
 
-def bMakeFolder(folder):
-    if not bIsExists(folder):
+def makeFolder(folder):
+    if not os.path.exists(folder):
         os.makedirs(folder)
 
 
-def bClearFolder(*folderAry):
+def clearFolder(*folderAry):
     for folder in folderAry:
-        if bIsFolder(folder):
-            for target in bGetFileAndFolderList(folder):
-                bRemove(target)
+        if os.path.isdir(folder):
+            for target in getFileAndFolderList(folder):
+                remove(target)
 
 
-def bCopy(fromFileOrFolder, toFileOrFolder):
-    if bIsFile(fromFileOrFolder):
+def copy(fromFileOrFolder, toFileOrFolder):
+    if os.path.isfile(fromFileOrFolder):
         fromFile = fromFileOrFolder
         toFile = toFileOrFolder
-        bMakeFolder(bGetParentFolder(toFile))
+        makeFolder(getParentFolder(toFile))
         shutil.copyfile(fromFile, toFile)
-    elif bIsFolder(fromFileOrFolder):
+    elif os.path.isdir(fromFileOrFolder):
         fromFolder = fromFileOrFolder
         toFolder = toFileOrFolder
-        bMakeFolder(bGetParentFolder(toFolder))
+        makeFolder(getParentFolder(toFolder))
         shutil.copytree(fromFolder, toFolder)
 
 
-def bRename(fromFileOrFolder, toFileOrFolder):
-    if bIsFile(fromFileOrFolder):
-        fromFile = fromFileOrFolder
-        toFile = toFileOrFolder
-        os.renames(fromFile, toFile)
-    elif bIsFolder(fromFileOrFolder):
-        fromFolder = fromFileOrFolder
-        toFolder = toFileOrFolder
-        os.renames(fromFolder, toFolder)
-
-
-def bGetParentFolder(fileOrFolder, level=1):
+def getParentFolder(fileOrFolder, level=1):
     result = fileOrFolder
     while level > 0:
         level -= 1
@@ -164,41 +153,29 @@ def bGetParentFolder(fileOrFolder, level=1):
     return result
 
 
-def bGetFileExtName(file):
+def getFileExtName(file):
     return file[file.rfind('.') + 1:].lower()
 
 
-def bIsFile(file):
-    return os.path.isfile(file)
-
-
-def bIsFolder(folder):
-    return os.path.isdir(folder)
-
-
-def bIsExists(fileOrFolder):
-    return os.path.exists(fileOrFolder)
-
-
-def bGetFileList(folder):
+def getFileList(folder):
     ary = []
     for targetName in os.listdir(folder):
         target = os.path.join(folder, targetName)
-        if bIsFile(target):
+        if os.path.isfile(target):
             ary.append(target)
     return ary
 
 
-def bGetFolderList(folder):
+def getFolderList(folder):
     ary = []
     for targetName in os.listdir(folder):
         target = os.path.join(folder, targetName)
-        if bIsFolder(target):
+        if os.path.isdir(target):
             ary.append(target)
     return ary
 
 
-def bGetFileAndFolderList(folder):
+def getFileAndFolderList(folder):
     ary = []
     for targetName in os.listdir(folder):
         target = os.path.join(folder, targetName)
@@ -206,62 +183,62 @@ def bGetFileAndFolderList(folder):
     return ary
 
 
-def bGetAllFileList(folder):
+def getAllFileList(folder):
     ary = []
-    for targetName in bGetFileAndFolderList(folder):
+    for targetName in getFileAndFolderList(folder):
         target = os.path.join(folder, targetName)
-        if bIsFile(target):
+        if os.path.isfile(target):
             ary.append(target)
-        elif bIsFolder(target):
-            ary.extend(bGetAllFileList(target))
+        elif os.path.isdir(target):
+            ary.extend(getAllFileList(target))
     return ary
 
 
-def bGetAllFolderList(folder):
+def getAllFolderList(folder):
     ary = []
-    for targetName in bGetFileAndFolderList(folder):
+    for targetName in getFileAndFolderList(folder):
         target = os.path.join(folder, targetName)
-        if bIsFolder(target):
+        if os.path.isdir(target):
             ary.append(target)
-            ary.extend(bGetAllFolderList(target))
+            ary.extend(getAllFolderList(target))
     return ary
 
 
-def bGetAllFileAndFolderList(folder):
+def getAllFileAndFolderList(folder):
     ary = []
-    for targetName in bGetFileAndFolderList(folder):
+    for targetName in getFileAndFolderList(folder):
         target = os.path.join(folder, targetName)
-        if bIsFile(target):
+        if os.path.isfile(target):
             ary.append(target)
-        elif bIsFolder(target):
+        elif os.path.isdir(target):
             ary.append(target)
-            ary.extend(bGetAllFileAndFolderList(target))
+            ary.extend(getAllFileAndFolderList(target))
     return ary
 
 
-def bGetFileMD5(file):
-    data = bReadBinFile(file)
+def getFileMD5(file):
+    data = readBinFile(file)
     return hashlib.md5(data).hexdigest()
 
 
-def bGetFileCRC32(file):
-    data = bReadBinFile(file)
+def getFileCRC32(file):
+    data = readBinFile(file)
     return binascii.crc32(data)
 
 
-def bGetFileCRCHex(file):
-    return hex(bGetFileCRC32(file))[2:].zfill(8)
+def getFileCRCHex(file):
+    return hex(getFileCRC32(file))[2:].zfill(8)
 
 
-def bGetContentCRCHex(content):
+def getContentCRCHex(content):
     return hex(binascii.crc32(content.encode()))[2:].zfill(8)
 
 
-def bGetClassFullName(classItem):
+def getClassFullName(classItem):
     return getattr(classItem, '__module__') + '.' + getattr(classItem, '__name__')
 
 
-def bExecute(*pars):
+def execute(*pars):
     p = subprocess.Popen(
         ' '.join(pars),
         shell=True,
@@ -273,9 +250,9 @@ def bExecute(*pars):
     return p.returncode, outBytes, errBytes
 
 
-def bExecuteWinScp(winscpExe, keyFile, server, commandAry, showCmd=False):
-    logFile = bGetPath(pathlib.Path.home(), "bExecuteWinScp.log")
-    bRemove(logFile)
+def executeWinScp(winscpExe, keyFile, server, commandAry, showCmd=False):
+    logFile = getPath(pathlib.Path.home(), "executeWinScp.log")
+    remove(logFile)
     ary = [
         'option batch abort',
         'option transfer binary',
@@ -289,13 +266,13 @@ def bExecuteWinScp(winscpExe, keyFile, server, commandAry, showCmd=False):
     # /console
     cmd = f'{winscpExe} /log={logFile} /loglevel=0 /command ' + ' '.join('"%s"' % x for x in ary)
     if showCmd:
-        bInfo(cmd)
-    return bExecute(cmd)
+        info(cmd)
+    return execute(cmd)
 
 
-def bZipFile(toFile, fileFolderOrAry, rename=None):
+def zipFile(toFile, fileFolderOrAry, rename=None):
     from zipfile import ZIP_DEFLATED, ZipFile
-    bMakeFolder(os.path.dirname(toFile))
+    makeFolder(os.path.dirname(toFile))
     ary = fileFolderOrAry
     if type(ary) != list:
         ary = [fileFolderOrAry]
@@ -306,17 +283,17 @@ def bZipFile(toFile, fileFolderOrAry, rename=None):
             f.write(file, fname)
 
 
-def bZipFileForFolder(toFile, folder, rename=None, filterFun=None):
+def zipFileForFolder(toFile, folder, rename=None, filterFun=None):
     if not folder.endswith(os.path.sep):
         folder += os.path.sep
     rename = rename or (lambda x: x[len(folder):])
-    ary = bGetAllFileAndFolderList(folder)
+    ary = getAllFileAndFolderList(folder)
     if filterFun:
         ary = list(filter(filterFun, ary))
-    bZipFile(toFile, ary, rename)
+    zipFile(toFile, ary, rename)
 
 
-def bZipFileExtract(file, toFolder=None):
+def zipFileExtract(file, toFolder=None):
     from zipfile import ZipFile
     toFolder = toFolder or os.path.dirname(file)
     with ZipFile(file) as f:
@@ -331,43 +308,43 @@ def bZipFileExtract(file, toFolder=None):
             f.extract(subFile, toFolder)
             # 处理压缩包中的中文文件名在windows下乱码
             if subFile != encodeSubFile:
-                bRename(os.path.join(toFolder, subFile), toFile)
+                os.renames(os.path.join(toFolder, subFile), toFile)
 
 
-def bSyncFolder(fromFolder, toFolder):
+def syncFolder(fromFolder, toFolder):
     # 删除多余目录
-    toSubFolderList = sorted(bGetAllFolderList(toFolder), reverse=True)
+    toSubFolderList = sorted(getAllFolderList(toFolder), reverse=True)
     for toSubFolder in toSubFolderList:
         fromSubFolder = os.path.join(fromFolder, toSubFolder[len(toFolder + os.path.sep):])
         if not os.path.isdir(fromSubFolder):
-            bRemove(toSubFolder)
+            remove(toSubFolder)
     # 删除多余文件
-    toFileList = bGetAllFileList(toFolder)
+    toFileList = getAllFileList(toFolder)
     for toFile in toFileList:
         fromFile = os.path.join(fromFolder, toFile[len(toFolder + os.path.sep):])
         if not os.path.isfile(fromFile):
-            bRemove(toFile)
+            remove(toFile)
     # 同步文件
-    fromFileList = bGetAllFileList(fromFolder)
+    fromFileList = getAllFileList(fromFolder)
     for fromFile in fromFileList:
         toFile = os.path.join(toFolder, fromFile[len(fromFolder + os.path.sep):])
         if os.path.isfile(toFile):
-            fromData = bReadBinFile(fromFile)
-            toData = bReadBinFile(toFile)
+            fromData = readBinFile(fromFile)
+            toData = readBinFile(toFile)
             if fromData != toData:
-                bWriteBinFile(toFile, fromData)
+                writeBinFile(toFile, fromData)
         else:
-            bRemove(toFile)
-            bCopy(fromFile, toFile)
+            remove(toFile)
+            copy(fromFile, toFile)
     # 添加新增目录
-    fromSubFolderList = sorted(bGetAllFolderList(fromFolder), reverse=True)
+    fromSubFolderList = sorted(getAllFolderList(fromFolder), reverse=True)
     for fromSubFolder in fromSubFolderList:
         toSubFolder = os.path.join(toFolder, fromSubFolder[len(fromFolder + os.path.sep):])
         if not os.path.isdir(toSubFolder):
-            bMakeFolder(toSubFolder)
+            makeFolder(toSubFolder)
 
 
-def bSendMail(host, password, fromMail, toMailList, subject, content='', attachmentList=None):
+def sendMail(host, password, fromMail, toMailList, subject, content='', attachmentList=None):
     '''发送邮件 attachmentList格式为[(name, bytes), ...]'''
 
     import smtplib
@@ -398,12 +375,12 @@ def bSendMail(host, password, fromMail, toMailList, subject, content='', attachm
 _DEFAULT_FMT = '%Y-%m-%d %H:%M:%S'
 
 
-def bTimestampByStr(value, fmt=None):
+def timestampByStr(value, fmt=None):
     fmt = fmt or _DEFAULT_FMT
     return int(time.mktime(time.strptime(value, fmt)))
 
 
-def bStrByTimestamp(timestamp=None, fmt=None):
+def strByTimestamp(timestamp=None, fmt=None):
     timestamp = timestamp or time.time()
     fmt = fmt or _DEFAULT_FMT
     ary = time.localtime(timestamp)
@@ -436,7 +413,7 @@ def _getHeaderByDefault(headers):
     return result
 
 
-def bHttpGet(url, headers=None, timeout=30, retry=3):
+def httpGet(url, headers=None, timeout=30, retry=3):
     method = 'GET'
     headers = _getHeaderByDefault(headers)
     result = None
@@ -458,7 +435,7 @@ def bHttpGet(url, headers=None, timeout=30, retry=3):
     return result, response
 
 
-def bHttpPost(url, data=None, headers=None, timeout=30, retry=3):
+def httpPost(url, data=None, headers=None, timeout=30, retry=3):
     method = 'POST'
     headers = _getHeaderByDefault(headers)
     postData = data
@@ -485,12 +462,12 @@ _currentAsyncFileNum = 0
 _waitAsyncFileTime = 0.5
 
 
-def bSetAsyncFileMaxNum(value):
+def setAsyncFileMaxNum(value):
     global _maxAsyncFileNum
     _maxAsyncFileNum = value
 
 
-def bToFloat(value, default):
+def toFloat(value, default):
     result = default
     try:
         result = float(value)
@@ -499,7 +476,7 @@ def bToFloat(value, default):
     return result
 
 
-def bToInt(value, default):
+def toInt(value, default):
     result = default
     try:
         result = int(value)
@@ -511,25 +488,25 @@ def bToInt(value, default):
 _xPar = "0123456789abcdefghijklmnopqrstuvwxyz"
 
 
-def bIntToX(value):
+def intToX(value):
     n = len(_xPar)
-    return ((value == 0) and "0") or (bIntToX(value // n).lstrip("0") + _xPar[value % n])
+    return ((value == 0) and "0") or (intToX(value // n).lstrip("0") + _xPar[value % n])
 
 
-def bXToInt(value):
+def xToInt(value):
     return int(value, len(_xPar))
 
 
-async def bAsyncAwait(*taskList):
+async def asyncAwait(*taskList):
     resultList = []
     for task in taskList:
         resultList.append(await task)
     return resultList
 
 
-async def bAsyncWriteFile(file, data, encoding='utf8', newline='\n'):
+async def asyncWriteFile(file, data, encoding='utf8', newline='\n'):
     import aiofiles
-    bMakeFolder(os.path.dirname(file))
+    makeFolder(os.path.dirname(file))
     global _currentAsyncFileNum
     while _currentAsyncFileNum > _maxAsyncFileNum:
         await asyncio.sleep(_waitAsyncFileTime)
@@ -541,9 +518,9 @@ async def bAsyncWriteFile(file, data, encoding='utf8', newline='\n'):
     _currentAsyncFileNum -= 1
 
 
-async def bAsyncWriteBinFile(file, data):
+async def asyncWriteBinFile(file, data):
     import aiofiles
-    bMakeFolder(os.path.dirname(file))
+    makeFolder(os.path.dirname(file))
     global _currentAsyncFileNum
     while _currentAsyncFileNum > _maxAsyncFileNum:
         await asyncio.sleep(_waitAsyncFileTime)
@@ -555,7 +532,7 @@ async def bAsyncWriteBinFile(file, data):
     _currentAsyncFileNum -= 1
 
 
-async def bAsyncReadFile(file, encoding='utf8', newline='\n'):
+async def asyncReadFile(file, encoding='utf8', newline='\n'):
     import aiofiles
     global _currentAsyncFileNum
     while _currentAsyncFileNum > _maxAsyncFileNum:
@@ -568,7 +545,7 @@ async def bAsyncReadFile(file, encoding='utf8', newline='\n'):
     return data
 
 
-async def bAsyncReadBinFile(file):
+async def asyncReadBinFile(file):
     import aiofiles
     global _currentAsyncFileNum
     while _currentAsyncFileNum > _maxAsyncFileNum:
@@ -581,28 +558,28 @@ async def bAsyncReadBinFile(file):
     return data
 
 
-async def bAsyncOpenXlsx(file):
+async def asyncOpenXlsx(file):
     import xlrd
-    data = await bAsyncReadBinFile(file)
+    data = await asyncReadBinFile(file)
     return xlrd.open_workbook(file_contents=data, formatting_info=True)
     # 只提供了异步打开xlsx的方法，没有提供异步写入xlsx的方法，因为xlwt不支持
 
 
-async def bAsyncGetFileMD5(file):
-    data = await bAsyncReadBinFile(file)
+async def asyncGetFileMD5(file):
+    data = await asyncReadBinFile(file)
     return hashlib.md5(data).hexdigest()
 
 
-async def bAsyncGetFileCRC32(file):
-    data = await bAsyncReadBinFile(file)
+async def asyncGetFileCRC32(file):
+    data = await asyncReadBinFile(file)
     return binascii.crc32(data)
 
 
-async def bAsyncGetFileCRCHex(file):
-    return hex(await bAsyncGetFileCRC32(file))[2:].zfill(8)
+async def asyncGetFileCRCHex(file):
+    return hex(await asyncGetFileCRC32(file))[2:].zfill(8)
 
 
-async def bAsyncExecute(*parList):
+async def asyncExecute(*parList):
     # 注意：针对windows，版本是3.8以下需要使用asyncio.subprocess，在执行main之前就要执行
     # 注意：在3.7如果调用对aiohttp有异常报错
     # asyncio.set_event_loop_policy(
@@ -623,12 +600,12 @@ _currentAsyncHttpNum = 0
 _waitAsyncHttpTime = 0.1
 
 
-def bSetAsyncHttpMaxNum(value):
+def setAsyncHttpMaxNum(value):
     global _maxAsyncHttpNum
     _maxAsyncHttpNum = value
 
 
-async def bAsyncHttpGet(url, headers=None, timeout=30, retry=3):
+async def asyncHttpGet(url, headers=None, timeout=30, retry=3):
     importAioHttp()
     global _currentAsyncHttpNum
     headers = _getHeaderByDefault(headers)
@@ -657,12 +634,12 @@ async def bAsyncHttpGet(url, headers=None, timeout=30, retry=3):
         except Exception:
             if response:
                 response.close()
-            bWarning(f'async http get exception url={url} times={currentTry}')
+            warning(f'async http get exception url={url} times={currentTry}')
     _currentAsyncHttpNum -= 1
     return result, response
 
 
-async def bAsyncHttpPost(url, data=None, headers=None, timeout=30, retry=3):
+async def asyncHttpPost(url, data=None, headers=None, timeout=30, retry=3):
     importAioHttp()
     global _currentAsyncHttpNum
     headers = _getHeaderByDefault(headers)
@@ -692,14 +669,14 @@ async def bAsyncHttpPost(url, data=None, headers=None, timeout=30, retry=3):
         except Exception:
             if response:
                 response.close()
-            bWarning(f'async http get exception url={url} times={currentTry}')
+            warning(f'async http get exception url={url} times={currentTry}')
     _currentAsyncHttpNum -= 1
     return result, response
 
 
-async def bAsyncDownload(url, file):
-    result, _response = await bAsyncHttpGet(url)
-    await bAsyncWriteBinFile(file, result)
+async def asyncDownload(url, file):
+    result, _response = await asyncHttpGet(url)
+    await asyncWriteBinFile(file, result)
 
 
 isImportAioHttp = True
@@ -730,7 +707,7 @@ def importAioHttp():
 
     _ProactorBasePipeTransport.__del__ = silence_event_loop_closed(_ProactorBasePipeTransport.__del__)
 
-# def bScrapy(urlList, parseFun, extendSettings=None):
+# def scrapy(urlList, parseFun, extendSettings=None):
 
 #     from scrapy.crawler import CrawlerProcess
 #     from scrapy.utils.log import get_scrapy_root_handler
@@ -781,7 +758,3 @@ def importAioHttp():
 #     logging.getLogger().handlers = []
 
 #     return resultList, resultUrlList
-
-
-if __name__ == '__main__':
-    pass
